#
# spec file for package python-virtkey
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major   0.63
Name:           python-virtkey
Version:        0.63.0
Release:        10.1
Summary:        Python extension to emulate keypresses
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://launchpad.net/virtkey
Source:         https://launchpad.net/virtkey/%{major}/%{version}/+download/virtkey-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xtst)
%python_subpackages

%description
python-virtkey is a python extension for emulating keypresses and
getting the keyboard geometry from the xserver.

%prep
%setup -q -n virtkey-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install

%files %{python_files}
%license COPYING.LESSER
%doc AUTHORS NEWS README
%{python_sitearch}/virtkey*.so
%{python_sitearch}/virtkey-%{version}*-info

%changelog
* Fri Jun 13 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Tue Jan 15 2013 vuntz@suse.com
- Add pre_checkin.sh and rework python3 packaging so that only
  updating the python-virtkey spec file is enough: the few
  differences between the two spec files are handled with a
  %%build_for_python3 define.
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support.
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to version 0.63.0:
  + Add support for system-layout specific items in Onboard's
    layout files
- Changes from version 0.62.0:
  + Allow arbitrary sequence of modifier masks
- Changes from version 0.61.0:
  + Add support for python3
  + Reduce the number of unnecessarily linked libraries
  + Make XkbGetKeyboard use correct constants
  + Switch the name of the source code package back to virtkey
- Cleanup the spec file a bit: drop non-openSUSE packaging bits.
- Add pkgconfig(xkbfile) BuildRequires: new dependency ypstream.
* Fri Feb 24 2012 vuntz@opensuse.org
- Add explicit pkgconfig(x11) and pkgconfig(xtst) BuildRequires:
  those are needed after the xorg-x11 packaging change.
- Change glib2-devel and gtk2-devel BuildRequires to the real
  pkgconfig() dependencies for this package: gdk-2.0 and glib-2.0.
* Sat Jul  2 2011 vuntz@opensuse.org
- Update to version 0.60.0:
  + Add methods to get the active layout symbols and group
    (lp#65626)
  + Add python error exit in getKbd (lp#526791)
  + Fix potential X resource leaks
  + Add test code to simulate missing X keyboard
  + Some code cleanup
  + Reorganize source directory and add AUTHORS, NEWS and README files
  + Add MANIFEST.in file
  + Use pkg-config to find paths instead of hardcoded paths
  + Update license to LGPL 3
  + Use 'python-virtkey' name also for source package
  + Change version format to major.minor.micro
  + Add some API documentation
- Change License tag from GPLv2+ to LGPLv3+.
- Drop python-virtkey-use-pkg-config.patch: fixed upstream.
- Update description
* Mon Dec 20 2010 saschpe@suse.de
- Re-packaged with py2pack to reduce build errors
* Fri Apr  2 2010 vuntz@opensuse.org
- New package.
